@@ -1,10 +1,10 @@
-from web_bb.core.base.api import (
-    READONLY_CATEGORY,
-    WRITE_CATEGORY,
-)
 from m3.actions import (
     Action,
 )
+from recordpack.recordpack import (
+    READONLY_CATEGORY,
+    WRITE_CATEGORY,
+)
 
 
 class ChangeElectronicDocumentStatusParametersDialogAction(Action):
